@@ -16,7 +16,7 @@
 #' @param makeNode A function that creates a \code{"SOCKnode"} or
 #' \code{"SOCK0node"} object, which represents a connection to a worker.
 #' 
-#' @param ... Optional arguments passed to
+#' @param \dots Optional arguments passed to
 #' \code{makeNode(workers[i], ..., rank = i)} where
 #' \code{i = seq_along(workers)}.
 #' 
@@ -47,13 +47,15 @@ makeClusterPSOCK <- function(workers, makeNode = makeNodePSOCK, port = c("auto",
   if (is.character(port)) {
     port <- match.arg(port)
     if (identical(port, "auto")) {
-      port0 <- Sys.getenv("R_PARALLEL_PORT")
-      port <- suppressWarnings(as.integer(port0))
-      if (is.na(port)) {
-        if (nzchar(port0)) {
-          warning("Non-numeric value of environment variable 'R_PARALLEL_PORT' coerced to NA_integer_: ", sQuote(port0))
-        }
+      port0 <- Sys.getenv("R_PARALLEL_PORT", "random")
+      if (identical(port0, "random")) {
         port <- 11000:11999
+      } else {
+        port <- suppressWarnings(as.integer(port0))
+        if (is.na(port)) {
+          warning("Non-numeric value of environment variable 'R_PARALLEL_PORT' coerced to NA_integer_: ", sQuote(port0))
+          port <- 11000:11999
+        }
       }
     } else if (identical(port, "random")) {
       port <- 11000:11999
@@ -149,7 +151,7 @@ makeClusterPSOCK <- function(workers, makeNode = makeNodePSOCK, port = c("auto",
 #' another host.
 #' 
 #' @param revtunnel If TRUE, a reverse SSH tunnel is set up for each worker such
-#' that the worker R process sets up a socket connection to its local port
+#' that the worker \R process sets up a socket connection to its local port
 #' \code{(port - rank + 1)} which then reaches the master on port \code{port}.
 #' If FALSE, then the worker will try to connect directly to port \code{port} on
 #' \code{master}.  For more details, see below.
@@ -183,15 +185,18 @@ makeClusterPSOCK <- function(workers, makeNode = makeNodePSOCK, port = c("auto",
 #' is given by option \code{future.makeNodePSOCK.rshcmd} and if that is not
 #' set the default is either of \command{ssh} and \command{plink -ssh}.
 #' Most Unix-like systems, including macOS, have \command{ssh} preinstalled
-#' on the \code{PATH}.  It is less common to find this command on Windows
-#' system, which are more likely to have the \command{PuTTY} software and
-#' its SSH client \command{plink} installed.
+#' on the \code{PATH}.  This is also true for recent Windows 10
+#' (since version 1803; April 2018).
 #' Furthermore, when running \R from RStudio on Windows, the \command{ssh}
 #' client that is distributed with RStudio will be used as a fallback if
 #' neither of the above two commands are available on the \code{PATH}.
-#' Note that on Windows 10, there is a beta version of OpenSSH that can
-#' be enabled in the Windows Settings, cf. \url{https://www.thomasmaurer.ch/2017/11/install-ssh-on-windows-10-as-optional-feature/}.
+#' 
+#' For Windows systems prior to Windows 10, which do not have RStudio
+#' installed, it is less common to find \command{ssh}. Instead it is more
+#' likely that such systems have the \command{PuTTY} software and its SSH
+#' client \command{plink} installed.
 #' If no SSH-client is found, an informative error message is produced.
+#' 
 #' It is also possible to specify the absolute path to the SSH client.  To do
 #' this for PuTTY, specify the absolute path in the first element and option
 #' \command{-ssh} in the second as in
@@ -225,7 +230,7 @@ makeClusterPSOCK <- function(workers, makeNode = makeNodePSOCK, port = c("auto",
 #' is available on the \code{PATH} of the worker.
 #' If \code{homogeneous} is TRUE, the \code{rscript} defaults to
 #' \code{file.path(R.home("bin"), "Rscript")}, i.e. it is basically assumed
-#' that the worker and the caller share the same file system and R installation.
+#' that the worker and the caller share the same file system and \R installation.
 #' 
 #' @section Default value of argument \code{homogeneous}:
 #' The default value of \code{homogeneous} is TRUE if and only if either
